pyppeteer: Headless chrome/chromium automation library
======================================================

Description
-----------

Headless chrome/chromium automation library (unofficial port of puppeteer)

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pyppeteer/

